@@ -233,7 +233,6 @@ class ADODB_ado extends ADOConnection {
 		return $arr;
 	}
 
-	/* returns queryID or false */
 	function _query($sql,$inputarr=false)
 	{
 		try { // In PHP5, all COM errors are exceptions, so to maintain old behaviour...
@@ -546,7 +545,13 @@ class ADORecordSet_ado extends ADORecordSet {
 			$len = $fieldobj->max_length;
 		}
 
-		if (!is_numeric($t)) return $t;
+		$t = strtoupper($t);
+
+		if (array_key_exists($t,$this->connection->customActualTypes))
+			return  $this->connection->customActualTypes[$t];
+
+		if (!is_numeric($t))
+			return $t;
 
 		switch ($t) {
 		case 0:
