@@ -256,7 +256,7 @@ class ADODB_ibase extends ADOConnection {
 
 
 	// See http://community.borland.com/article/0,1410,25844,00.html
-	function RowLock($tables,$where,$col=false)
+	function rowLock($table, $where, $col = false)
 	{
 		if ($this->autoCommit) {
 			$this->BeginTrans();
@@ -320,7 +320,7 @@ class ADODB_ibase extends ADOConnection {
 
 	function ErrorMsg()
 	{
-			return $this->_errorMsg;
+		return $this->_errorMsg;
 	}
 
 	function Prepare($sql)
@@ -332,9 +332,8 @@ class ADODB_ibase extends ADOConnection {
 
 	// returns query ID if successful, otherwise false
 	// there have been reports of problems with nested queries - the code is probably not re-entrant?
-	function _query($sql,$iarr=false)
+	function _query($sql, $inputarr = false)
 	{
-
 		if (!$this->autoCommit && $this->_transactionID) {
 			$conn = $this->_transactionID;
 			$docommit = false;
@@ -345,28 +344,35 @@ class ADODB_ibase extends ADOConnection {
 		if (is_array($sql)) {
 			$fn = 'ibase_execute';
 			$sql = $sql[1];
-			if (is_array($iarr)) {
-				if ( !isset($iarr[0]) ) 
-					$iarr[0] = ''; // PHP5 compat hack
-				$fnarr = array_merge( array($sql) , $iarr);
-				$ret = call_user_func_array($fn,$fnarr);
-			}
-			else {
+			if (is_array($inputarr)) {
+				if (!isset($inputarr[0])) {
+					$inputarr[0] = '';  // PHP5 compat hack
+				}
+				$fnarr = array_merge(array($sql), $inputarr);
+				$ret = call_user_func_array($fn, $fnarr);
+			} else {
 				$ret = $fn($sql);
 			}
 		} else {
 			$fn = 'ibase_query';
 
-			if (is_array($iarr)) {
-				if (sizeof($iarr) == 0) 
-					$iarr[0] = ''; // PHP5 compat hack
-				$fnarr = array_merge( array($conn,$sql) , $iarr);
-				$ret = call_user_func_array($fn,$fnarr);
-			}
-			else {
+			if (is_array($inputarr)) {
+				if (sizeof($inputarr) == 0) {
+					$inputarr[0] = ''; // PHP5 compat hack
+				}
+				$fnarr = array_merge(array($conn, $sql), $inputarr);
+				$ret = call_user_func_array($fn, $fnarr);
+			} else {
 				$ret = $fn($conn, $sql);
 			}
 		}
+
+		// ibase_query() and ibase_execute() return number of affected rows
+		// ADOConnection::_Execute() expects true for INSERT/UPDATE/DELETE
+		if (is_numeric($ret)) {
+			$ret = true;
+		}
+
 		if ($docommit && $ret === true) {
 			ibase_commit($this->_connectionID);
 		}
@@ -514,17 +520,24 @@ class ADODB_ibase extends ADOConnection {
 
 				$fld->has_default = true;
 				$d = substr($rs->fields[2],strlen('default '));
-				switch ($fld->type)
-				{
-				case 'smallint':
-				case 'integer': $fld->default_value = (int) $d; break;
-				case 'char':
-				case 'blob':
-				case 'text':
-				case 'varchar': $fld->default_value = (string) substr($d,1,strlen($d)-2); break;
-				case 'double':
-				case 'float': $fld->default_value = (float) $d; break;
-				default: $fld->default_value = $d; break;
+				switch ($fld->type) {
+					case 'smallint':
+					case 'integer':
+						$fld->default_value = (int)$d;
+						break;
+					case 'char':
+					case 'blob':
+					case 'text':
+					case 'varchar':
+						$fld->default_value = (string)substr($d, 1, strlen($d) - 2);
+						break;
+					case 'double':
+					case 'float':
+						$fld->default_value = (float)$d;
+						break;
+					default:
+						$fld->default_value = $d;
+						break;
 				}
 		//	case 35:$tt = 'TIMESTAMP'; break;
 			}
@@ -558,9 +571,6 @@ class ADODB_ibase extends ADOConnection {
 		return $blob;
 	}
 
-
-
-
 	// old blobdecode function
 	// still used to auto-decode all blob's
 	function _BlobDecode_old( $blob )
@@ -625,34 +635,34 @@ class ADODB_ibase extends ADOConnection {
 	*/
 	function UpdateBlob($table,$column,$val,$where,$blobtype='BLOB')
 	{
-	$blob_id = ibase_blob_create($this->_connectionID);
+		$blob_id = ibase_blob_create($this->_connectionID);
 
-	// ibase_blob_add($blob_id, $val);
+		// ibase_blob_add($blob_id, $val);
 
-	// replacement that solves the problem by which only the first modulus 64K /
-	// of $val are stored at the blob field ////////////////////////////////////
-	// Thx Abel Berenstein  aberenstein#afip.gov.ar
-	$len = strlen($val);
-	$chunk_size = 32768;
-	$tail_size = $len % $chunk_size;
-	$n_chunks = ($len - $tail_size) / $chunk_size;
+		// replacement that solves the problem by which only the first modulus 64K /
+		// of $val are stored at the blob field ////////////////////////////////////
+		// Thx Abel Berenstein  aberenstein#afip.gov.ar
+		$len = strlen($val);
+		$chunk_size = 32768;
+		$tail_size = $len % $chunk_size;
+		$n_chunks = ($len - $tail_size) / $chunk_size;
 
-	for ($n = 0; $n < $n_chunks; $n++) {
-		$start = $n * $chunk_size;
-		$data = substr($val, $start, $chunk_size);
-		ibase_blob_add($blob_id, $data);
-	}
+		for ($n = 0; $n < $n_chunks; $n++) {
+			$start = $n * $chunk_size;
+			$data = substr($val, $start, $chunk_size);
+			ibase_blob_add($blob_id, $data);
+		}
 
-	if ($tail_size) {
-		$start = $n_chunks * $chunk_size;
-		$data = substr($val, $start, $tail_size);
-		ibase_blob_add($blob_id, $data);
-	}
-	// end replacement /////////////////////////////////////////////////////////
+		if ($tail_size) {
+			$start = $n_chunks * $chunk_size;
+			$data = substr($val, $start, $tail_size);
+			ibase_blob_add($blob_id, $data);
+		}
+		// end replacement /////////////////////////////////////////////////////////
 
-	$blob_id_str = ibase_blob_close($blob_id);
+		$blob_id_str = ibase_blob_close($blob_id);
 
-	return $this->Execute("UPDATE $table SET $column=(?) WHERE $where",array($blob_id_str)) != false;
+		return $this->Execute("UPDATE $table SET $column=(?) WHERE $where", array($blob_id_str)) != false;
 
 	}
 
@@ -724,7 +734,7 @@ class ADODB_ibase extends ADOConnection {
 	Class Name: Recordset
 --------------------------------------------------------------------------------------*/
 
-class ADORecordset_ibase extends ADORecordSet
+class ADORecordSet_ibase extends ADORecordSet
 {
 
 	var $databaseType = "ibase";
@@ -844,13 +854,12 @@ class ADORecordset_ibase extends ADORecordSet
 		}
 
 		return $this->fields[$this->bind[strtoupper($colname)]];
-
 	}
 
 
 	function _close()
 	{
-			return @ibase_free_result($this->_queryID);
+		return @ibase_free_result($this->_queryID);
 	}
 
 	function MetaType($t,$len=-1,$fieldobj=false)
@@ -860,28 +869,41 @@ class ADORecordset_ibase extends ADORecordSet
 			$t = $fieldobj->type;
 			$len = $fieldobj->max_length;
 		}
-		switch (strtoupper($t)) {
-		case 'CHAR':
-			return 'C';
 
-		case 'TEXT':
-		case 'VARCHAR':
-		case 'VARYING':
-		if ($len <= $this->blobSize) return 'C';
-			return 'X';
-		case 'BLOB':
-			return 'B';
+		$t = strtoupper($t);
 
-		case 'TIMESTAMP':
-		case 'DATE': return 'D';
-		case 'TIME': return 'T';
-				//case 'T': return 'T';
+		if (array_key_exists($t, $this->connection->customActualTypes)) {
+			return $this->connection->customActualTypes[$t];
+		}
 
-				//case 'L': return 'L';
-		case 'INT':
-		case 'SHORT':
-		case 'INTEGER': return 'I';
-		default: return ADODB_DEFAULT_METATYPE;
+		switch ($t) {
+			case 'CHAR':
+				return 'C';
+
+			case 'TEXT':
+			case 'VARCHAR':
+			case 'VARYING':
+				if ($len <= $this->blobSize) {
+					return 'C';
+				}
+				return 'X';
+			case 'BLOB':
+				return 'B';
+
+			case 'TIMESTAMP':
+			case 'DATE':
+				return 'D';
+			case 'TIME':
+				return 'T';
+			//case 'T': return 'T';
+
+			//case 'L': return 'L';
+			case 'INT':
+			case 'SHORT':
+			case 'INTEGER':
+				return 'I';
+			default:
+				return ADODB_DEFAULT_METATYPE;
 		}
 	}
 
