@@ -1,24 +1,29 @@
 <?php
-/*
-@version   v5.20.19  13-Dec-2020
-@copyright (c) 2000-2013 John Lim (jlim#natsoft.com). All rights reserved.
-@copyright (c) 2014      Damien Regad, Mark Newnham and the ADOdb community
-  Released under both BSD license and Lesser GPL library license.
-  Whenever there is any discrepancy between the two licenses,
-  the BSD license will take precedence.
-Set tabs to 4 for best viewing.
-
-  Latest version is available at http://adodb.org/
-
-  SAPDB data driver. Requires ODBC.
-
-*/
+/**
+ * SAPDB data driver
+ *
+ * This file is part of ADOdb, a Database Abstraction Layer library for PHP.
+ *
+ * @package ADOdb
+ * @link https://adodb.org Project's web site and documentation
+ * @link https://github.com/ADOdb/ADOdb Source code and issue tracker
+ *
+ * The ADOdb Library is dual-licensed, released under both the BSD 3-Clause
+ * and the GNU Lesser General Public Licence (LGPL) v2.1 or, at your option,
+ * any later version. This means you can use it in proprietary products.
+ * See the LICENSE.md file distributed with this source code for details.
+ * @license BSD-3-Clause
+ * @license LGPL-2.1-or-later
+ *
+ * @copyright 2000-2013 John Lim
+ * @copyright 2014 Damien Regad, Mark Newnham and the ADOdb community
+ */
 
 // security - hide paths
 if (!defined('ADODB_DIR')) die();
 
 if (!defined('_ADODB_ODBC_LAYER')) {
-	include(ADODB_DIR."/drivers/adodb-odbc.inc.php");
+	include_once(ADODB_DIR."/drivers/adodb-odbc.inc.php");
 }
 if (!defined('ADODB_SAPDB')){
 define('ADODB_SAPDB',1);
@@ -33,12 +38,6 @@ class ADODB_SAPDB extends ADODB_odbc {
 	var $hasInsertId = true;
 	var $_bindInputArray = true;
 
-	function __construct()
-	{
-		//if (strncmp(PHP_OS,'WIN',3) === 0) $this->curmode = SQL_CUR_USE_ODBC;
-		parent::__construct();
-	}
-
 	function ServerInfo()
 	{
 		$info = ADODB_odbc::ServerInfo();
@@ -55,7 +54,7 @@ class ADODB_SAPDB extends ADODB_odbc {
 		return $this->GetCol("SELECT columnname FROM COLUMNS WHERE tablename=$table AND mode='KEY' ORDER BY pos");
 	}
 
- 	function MetaIndexes ($table, $primary = FALSE, $owner = false)
+	function MetaIndexes ($table, $primary = FALSE, $owner = false)
 	{
 		$table = $this->Quote(strtoupper($table));
 
@@ -65,43 +64,43 @@ class ADODB_SAPDB extends ADODB_odbc {
 
 		global $ADODB_FETCH_MODE;
 		$save = $ADODB_FETCH_MODE;
-        $ADODB_FETCH_MODE = ADODB_FETCH_NUM;
-        if ($this->fetchMode !== FALSE) {
-        	$savem = $this->SetFetchMode(FALSE);
-        }
+		$ADODB_FETCH_MODE = ADODB_FETCH_NUM;
+		if ($this->fetchMode !== FALSE) {
+			$savem = $this->SetFetchMode(FALSE);
+		}
 
-        $rs = $this->Execute($sql);
-        if (isset($savem)) {
-        	$this->SetFetchMode($savem);
-        }
-        $ADODB_FETCH_MODE = $save;
+		$rs = $this->Execute($sql);
+		if (isset($savem)) {
+			$this->SetFetchMode($savem);
+		}
+		$ADODB_FETCH_MODE = $save;
 
-        if (!is_object($rs)) {
-        	return FALSE;
-        }
+		if (!is_object($rs)) {
+			return FALSE;
+		}
 
 		$indexes = array();
 		while ($row = $rs->FetchRow()) {
-            $indexes[$row[0]]['unique'] = $row[1] == 'UNIQUE';
-            $indexes[$row[0]]['columns'][] = $row[2];
-    	}
+			$indexes[$row[0]]['unique'] = $row[1] == 'UNIQUE';
+			$indexes[$row[0]]['columns'][] = $row[2];
+		}
 		if ($primary) {
 			$indexes['SYSPRIMARYKEYINDEX'] = array(
 					'unique' => True,	// by definition
 					'columns' => $this->GetCol("SELECT columnname FROM COLUMNS WHERE tablename=$table AND mode='KEY' ORDER BY pos"),
 				);
 		}
-        return $indexes;
+		return $indexes;
 	}
 
 	function MetaColumns ($table, $normalize = true)
 	{
 		global $ADODB_FETCH_MODE;
 		$save = $ADODB_FETCH_MODE;
-        $ADODB_FETCH_MODE = ADODB_FETCH_NUM;
-        if ($this->fetchMode !== FALSE) {
-        	$savem = $this->SetFetchMode(FALSE);
-        }
+		$ADODB_FETCH_MODE = ADODB_FETCH_NUM;
+		if ($this->fetchMode !== FALSE) {
+			$savem = $this->SetFetchMode(FALSE);
+		}
 		$table = $this->Quote(strtoupper($table));
 
 		$retarr = array();
@@ -134,10 +133,10 @@ class ADODB_SAPDB extends ADODB_odbc {
 			}
 			$retarr[$fld->name] = $fld;
 		}
-        if (isset($savem)) {
-        	$this->SetFetchMode($savem);
-        }
-        $ADODB_FETCH_MODE = $save;
+		if (isset($savem)) {
+			$this->SetFetchMode($savem);
+		}
+		$ADODB_FETCH_MODE = $save;
 
 		return $retarr;
 	}
@@ -150,7 +149,7 @@ class ADODB_SAPDB extends ADODB_odbc {
 	}
 
 	// unlike it seems, this depends on the db-session and works in a multiuser environment
-	function _insertid($table,$column)
+	protected function _insertID($table = '', $column = '')
 	{
 		return empty($table) ? False : $this->GetOne("SELECT $table.CURRVAL FROM DUAL");
 	}
@@ -158,13 +157,13 @@ class ADODB_SAPDB extends ADODB_odbc {
 	/*
 		SelectLimit implementation problems:
 
-	 	The following will return random 10 rows as order by performed after "WHERE rowno<10"
-	 	which is not ideal...
+		The following will return random 10 rows as order by performed after "WHERE rowno<10"
+		which is not ideal...
 
-	  		select * from table where rowno < 10 order by 1
+			select * from table where rowno < 10 order by 1
 
-	  	This means that we have to use the adoconnection base class SelectLimit when
-	  	there is an "order by".
+		This means that we have to use the adoconnection base class SelectLimit when
+		there is an "order by".
 
 		See http://listserv.sap.com/pipermail/sapdb.general/2002-January/010405.html
 	 */
@@ -172,14 +171,10 @@ class ADODB_SAPDB extends ADODB_odbc {
 };
 
 
-class  ADORecordSet_sapdb extends ADORecordSet_odbc {
+class ADORecordSet_sapdb extends ADORecordSet_odbc {
 
 	var $databaseType = "sapdb";
 
-	function __construct($id,$mode=false)
-	{
-		parent::__construct($id,$mode);
-	}
 }
 
 } //define
